@@ -17,15 +17,15 @@ class IRIVER_STORY(USBMS):
     supported_platforms = ['windows', 'osx', 'linux']
 
     # Ordered list of supported formats
-    FORMATS     = ['epub', 'pdf', 'txt']
+    FORMATS     = ['epub', 'fb2', 'pdf', 'djvu', 'txt']
 
     VENDOR_ID   = [0x1006]
-    PRODUCT_ID  = [0x4023]
+    PRODUCT_ID  = [0x4023, 0x4025]
     BCD         = [0x0323]
 
     VENDOR_NAME = 'IRIVER'
-    WINDOWS_MAIN_MEM = 'STORY'
-    WINDOWS_CARD_A_MEM = 'STORY'
+    WINDOWS_MAIN_MEM = ['STORY', 'STORY_EB05']
+    WINDOWS_CARD_A_MEM = ['STORY', 'STORY_SD']
 
     #OSX_MAIN_MEM = 'Kindle Internal Storage Media'
     #OSX_CARD_A_MEM = 'Kindle Card Storage Media'
