@@ -9,10 +9,10 @@ Device driver for the SONY devices
 import os, time, re
 
 from calibre.devices.usbms.driver import USBMS, debug_print
-from calibre.devices.prs505 import MEDIA_XML
-from calibre.devices.prs505 import CACHE_XML
+from calibre.devices.prs505 import MEDIA_XML, MEDIA_EXT, CACHE_XML, CACHE_EXT, \
+            MEDIA_THUMBNAIL, CACHE_THUMBNAIL
 from calibre.devices.prs505.sony_cache import XMLCache
-from calibre import __appname__
+from calibre import __appname__, prints
 from calibre.devices.usbms.books import CollectionsBookList
 
 class PRS505(USBMS):
@@ -27,7 +27,7 @@ class PRS505(USBMS):
 
 
     FORMATS      = ['epub', 'lrf', 'lrx', 'rtf', 'pdf', 'txt']
-    CAN_SET_METADATA = True
+    CAN_SET_METADATA = ['title', 'authors', 'collections']
 
     VENDOR_ID    = [0x054c]   #: SONY Vendor Id
     PRODUCT_ID   = [0x031e]
@@ -35,16 +35,16 @@ class PRS505(USBMS):
 
     VENDOR_NAME        = 'SONY'
     WINDOWS_MAIN_MEM   = re.compile(
-            r'(PRS-(505|300|500))|'
-            r'(PRS-((700[#/])|((6|9)00&)))'
+            r'(PRS-(505|500|300))|'
+            r'(PRS-((700[#/])|((6|9|3)(0|5)0&)))'
             )
     WINDOWS_CARD_A_MEM = re.compile(
             r'(PRS-(505|500)[#/]\S+:MS)|'
-            r'(PRS-((700[/#]\S+:)|((6|9)00[#_]))MS)'
+            r'(PRS-((700[/#]\S+:)|((6|9)(0|5)0[#_]))MS)'
             )
     WINDOWS_CARD_B_MEM = re.compile(
             r'(PRS-(505|500)[#/]\S+:SD)|'
-            r'(PRS-((700[/#]\S+:)|((6|9)00[#_]))SD)'
+            r'(PRS-((700[/#]\S+:)|((6|9)(0|5)0[#_]))SD)'
             )
 
 
@@ -63,6 +63,11 @@ class PRS505(USBMS):
                     'series, tags, authors'
     EXTRA_CUSTOMIZATION_DEFAULT = ', '.join(['series', 'tags'])
 
+    plugboard = None
+    plugboard_func = None
+
+    THUMBNAIL_HEIGHT = 200
+
     def windows_filter_pnp_id(self, pnp_id):
         return '_LAUNCHER' in pnp_id
 
@@ -113,20 +118,21 @@ class PRS505(USBMS):
         return fname
 
     def initialize_XML_cache(self):
-        paths, prefixes = {}, {}
-        for prefix, path, source_id in [
-                ('main', MEDIA_XML, 0),
-                ('card_a', CACHE_XML, 1),
-                ('card_b', CACHE_XML, 2)
+        paths, prefixes, ext_paths = {}, {}, {}
+        for prefix, path, ext_path, source_id in [
+                ('main', MEDIA_XML, MEDIA_EXT, 0),
+                ('card_a', CACHE_XML, CACHE_EXT, 1),
+                ('card_b', CACHE_XML, CACHE_EXT, 2)
                 ]:
             prefix = getattr(self, '_%s_prefix'%prefix)
             if prefix is not None and os.path.exists(prefix):
                 paths[source_id] = os.path.join(prefix, *(path.split('/')))
+                ext_paths[source_id] = os.path.join(prefix, *(ext_path.split('/')))
                 prefixes[source_id] = prefix
                 d = os.path.dirname(paths[source_id])
                 if not os.path.exists(d):
                     os.makedirs(d)
-        return XMLCache(paths, prefixes, self.settings().use_author_sort)
+        return XMLCache(paths, ext_paths, prefixes, self.settings().use_author_sort)
 
     def books(self, oncard=None, end_session=True):
         debug_print('PRS505: starting fetching books for card', oncard)
@@ -150,7 +156,12 @@ class PRS505(USBMS):
         else:
             collections = []
         debug_print('PRS505: collection fields:', collections)
-        c.update(blists, collections)
+        pb = None
+        if self.plugboard_func:
+            pb = self.plugboard_func(self.__class__.__name__,
+                                     'device_db', self.plugboards)
+        debug_print('PRS505: use plugboards', pb)
+        c.update(blists, collections, pb)
         c.write()
 
         USBMS.sync_booklists(self, booklists, end_session=end_session)
@@ -163,3 +174,36 @@ class PRS505(USBMS):
         c.write()
         debug_print('PRS505: finished rebuild_collections')
 
+    def set_plugboards(self, plugboards, pb_func):
+        self.plugboards = plugboards
+        self.plugboard_func = pb_func
+
+    def upload_cover(self, path, filename, metadata, filepath):
+        if metadata.thumbnail and metadata.thumbnail[-1]:
+            path = path.replace('/', os.sep)
+            is_main = path.startswith(self._main_prefix)
+            thumbnail_dir = MEDIA_THUMBNAIL if is_main else CACHE_THUMBNAIL
+            prefix = None
+            if is_main:
+                prefix = self._main_prefix
+            else:
+                if self._card_a_prefix and \
+                    path.startswith(self._card_a_prefix):
+                    prefix = self._card_a_prefix
+                elif self._card_b_prefix and \
+                        path.startswith(self._card_b_prefix):
+                    prefix = self._card_b_prefix
+            if prefix is None:
+                prints('WARNING: Failed to find prefix for:', filepath)
+                return
+            thumbnail_dir = os.path.join(prefix, *thumbnail_dir.split('/'))
+
+            relpath = os.path.relpath(filepath, prefix)
+            if relpath.startswith('..\\'):
+                relpath = relpath[3:]
+            thumbnail_dir = os.path.join(thumbnail_dir, relpath)
+            if not os.path.exists(thumbnail_dir):
+                os.makedirs(thumbnail_dir)
+            with open(os.path.join(thumbnail_dir, 'main_thumbnail.jpg'), 'wb') as f:
+                f.write(metadata.thumbnail[-1])
+
