@@ -25,6 +25,7 @@ from calibre.translations.dynamic import translate
 from calibre.ebooks.chardet import xml_to_unicode
 from calibre.ebooks.oeb.entitydefs import ENTITYDEFS
 from calibre.ebooks.conversion.preprocess import CSSPreProcessor
+from calibre import isbytestring
 
 RECOVER_PARSER = etree.XMLParser(recover=True, no_network=True)
 
@@ -282,9 +283,9 @@ def XPath(expr):
 def xpath(elem, expr):
     return elem.xpath(expr, namespaces=XPNSMAP)
 
-def xml2str(root, pretty_print=False, strip_comments=False):
+def xml2str(root, pretty_print=False, strip_comments=False, with_tail=True):
     ans = etree.tostring(root, encoding='utf-8', xml_declaration=True,
-                          pretty_print=pretty_print)
+                          pretty_print=pretty_print, with_tail=with_tail)
 
     if strip_comments:
         ans = re.compile(r'<!--.*?-->', re.DOTALL).sub('', ans)
@@ -404,7 +405,8 @@ class DirContainer(object):
 
     def __init__(self, path, log):
         self.log = log
-        path = unicode(path)
+        if isbytestring(path):
+            path = path.decode(filesystem_encoding)
         ext = os.path.splitext(path)[1].lower()
         if ext == '.opf':
             self.opfname = os.path.basename(path)
@@ -654,8 +656,6 @@ class Metadata(object):
             if predicate(x):
                 l.remove(x)
 
-
-
     def __getitem__(self, key):
         return self.items[key]
 
@@ -787,6 +787,8 @@ class Manifest(object):
             # Convert to Unicode and normalize line endings
             data = self.oeb.decode(data)
             data = self.oeb.html_preprocessor(data)
+            # There could be null bytes in data if it had &#0; entities in it
+            data = data.replace('\0', '')
 
             # Remove DOCTYPE declaration as it messes up parsing
             # In particular, it causes tostring to insert xmlns
@@ -1910,6 +1912,7 @@ class OEBBook(object):
 
     def _to_ncx(self):
         lang = unicode(self.metadata.language[0])
+        lang = lang.replace('_', '-')
         ncx = etree.Element(NCX('ncx'),
             attrib={'version': '2005-1', XML('lang'): lang},
             nsmap={None: NCX_NS})
