@@ -15,7 +15,7 @@ from PyQt4.Qt import QComboBox, QLabel, QSpinBox, QDoubleSpinBox, QDateEdit, \
 
 from calibre.utils.date import qt_to_dt, now
 from calibre.gui2.widgets import TagsLineEdit, EnComboBox
-from calibre.gui2 import UNDEFINED_QDATE
+from calibre.gui2 import UNDEFINED_QDATE, error_dialog
 from calibre.utils.config import tweaks
 
 class Base(object):
@@ -310,6 +310,49 @@ class Series(Base):
             self.db.set_custom(book_id, val, extra=s_index,
                                num=self.col_id, notify=notify, commit=False)
 
+class Enumeration(Base):
+
+    def setup_ui(self, parent):
+        self.parent = parent
+        self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent),
+                QComboBox(parent)]
+        w = self.widgets[1]
+        vals = self.col_metadata['display']['enum_values']
+        w.addItem('')
+        for v in vals:
+            w.addItem(v)
+
+    def initialize(self, book_id):
+        val = self.db.get_custom(book_id, num=self.col_id, index_is_id=True)
+        val = self.normalize_db_val(val)
+        self.initial_val = val
+        idx = self.widgets[1].findText(val)
+        if idx < 0:
+            error_dialog(self.parent, '',
+                    _('The enumeration "{0}" contains an invalid value '
+                      'that will be set to the default').format(
+                                            self.col_metadata['name']),
+                    show=True, show_copy_button=False)
+
+            idx = 0
+        self.widgets[1].setCurrentIndex(idx)
+
+    def setter(self, val):
+        self.widgets[1].setCurrentIndex(self.widgets[1].findText(val))
+
+    def getter(self):
+        return unicode(self.widgets[1].currentText())
+
+    def normalize_db_val(self, val):
+        if val is None:
+            val = ''
+        return val
+
+    def normalize_ui_val(self, val):
+        if not val:
+            val = None
+        return val
+
 widgets = {
         'bool' : Bool,
         'rating' : Rating,
@@ -319,6 +362,7 @@ widgets = {
         'text' : Text,
         'comments': Comments,
         'series': Series,
+        'enumeration': Enumeration
 }
 
 def field_sort(y, z, x=None):
@@ -437,7 +481,7 @@ class BulkBool(BulkBase, Bool):
             if tweaks['bool_custom_columns_are_tristate'] == 'no' and val is None:
                 val = False
             if value is not None and value != val:
-                return None
+                return 'nochange'
             value = val
         return value
 
@@ -445,19 +489,23 @@ class BulkBool(BulkBase, Bool):
         self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent),
                 QComboBox(parent)]
         w = self.widgets[1]
-        items = [_('Yes'), _('No'), _('Undefined')]
-        icons = [I('ok.png'), I('list_remove.png'), I('blank.png')]
+        items = [_('Yes'), _('No'), _('Undefined'), _('Do not change')]
+        icons = [I('ok.png'), I('list_remove.png'), I('blank.png'), I('blank.png')]
         for icon, text in zip(icons, items):
             w.addItem(QIcon(icon), text)
 
+    def getter(self):
+        val = self.widgets[1].currentIndex()
+        return {3: 'nochange', 2: None, 1: False, 0: True}[val]
+
     def setter(self, val):
-        val = {None: 2, False: 1, True: 0}[val]
+        val = {'nochange': 3, None: 2, False: 1, True: 0}[val]
         self.widgets[1].setCurrentIndex(val)
 
     def commit(self, book_ids, notify=False):
         val = self.gui_val
         val = self.normalize_ui_val(val)
-        if val != self.initial_val:
+        if val != self.initial_val and val != 'nochange':
             if tweaks['bool_custom_columns_are_tristate'] == 'no' and val is None:
                 val = False
             self.db.set_custom_bulk(book_ids, val, num=self.col_id, notify=notify)
@@ -547,6 +595,61 @@ class BulkSeries(BulkBase):
             self.db.set_custom_bulk(book_ids, val, extras=extras,
                                    num=self.col_id, notify=notify)
 
+class BulkEnumeration(BulkBase, Enumeration):
+
+    def get_initial_value(self, book_ids):
+        value = None
+        ret_value = None
+        dialog_shown = False
+        for book_id in book_ids:
+            val = self.db.get_custom(book_id, num=self.col_id, index_is_id=True)
+            if val and val not in self.col_metadata['display']['enum_values']:
+                if not dialog_shown:
+                    error_dialog(self.parent, '',
+                            _('The enumeration "{0}" contains invalid values '
+                              'that will not appear in the list').format(
+                                                    self.col_metadata['name']),
+                            show=True, show_copy_button=False)
+                    dialog_shown = True
+                ret_value = ' nochange '
+            elif value is not None and value != val:
+                ret_value = ' nochange '
+            value = val
+        if ret_value is None:
+            return value
+        return ret_value
+
+    def setup_ui(self, parent):
+        self.parent = parent
+        self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent),
+                QComboBox(parent)]
+        w = self.widgets[1]
+        vals = self.col_metadata['display']['enum_values']
+        w.addItem('Do Not Change')
+        w.addItem('')
+        for v in vals:
+            w.addItem(v)
+
+    def getter(self):
+        if self.widgets[1].currentIndex() == 0:
+            return ' nochange '
+        return unicode(self.widgets[1].currentText())
+
+    def setter(self, val):
+        if val == ' nochange ':
+            self.widgets[1].setCurrentIndex(0)
+        else:
+            if val is None:
+                self.widgets[1].setCurrentIndex(1)
+            else:
+                self.widgets[1].setCurrentIndex(self.widgets[1].findText(val))
+
+    def commit(self, book_ids, notify=False):
+        val = self.gui_val
+        val = self.normalize_ui_val(val)
+        if val != self.initial_val and val != ' nochange ':
+            self.db.set_custom_bulk(book_ids, val, num=self.col_id, notify=notify)
+
 class RemoveTags(QWidget):
 
     def __init__(self, parent, values):
@@ -652,4 +755,5 @@ bulk_widgets = {
         'datetime': BulkDateTime,
         'text' : BulkText,
         'series': BulkSeries,
+        'enumeration': BulkEnumeration,
 }
