@@ -6,7 +6,7 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 import re
 
 from PyQt4.Qt import Qt, QDialog, QGridLayout, QVBoxLayout, QFont, QLabel, \
-                     pyqtSignal
+                     pyqtSignal, QDialogButtonBox
 from PyQt4 import QtGui
 
 from calibre.gui2.dialogs.metadata_bulk_ui import Ui_MetadataBulkDialog
@@ -197,7 +197,7 @@ class MetadataBulkDialog(QDialog, Ui_MetadataBulkDialog):
                             _('Append to field'),
                         ]
 
-    def __init__(self, window, rows, model):
+    def __init__(self, window, rows, model, tab):
         QDialog.__init__(self, window)
         Ui_MetadataBulkDialog.__init__(self)
         self.setupUi(self)
@@ -232,8 +232,20 @@ class MetadataBulkDialog(QDialog, Ui_MetadataBulkDialog):
             self.create_custom_column_editors()
 
         self.prepare_search_and_replace()
+
+        self.button_box.clicked.connect(self.button_clicked)
+        self.button_box.button(QDialogButtonBox.Apply).setToolTip(_(
+            'Immediately make all changes without closing the dialog. '
+            'This operation cannot be canceled or undone'))
+        self.do_again = False
+        self.central_widget.setCurrentIndex(tab)
         self.exec_()
 
+    def button_clicked(self, which):
+        if which == self.button_box.button(QDialogButtonBox.Apply):
+            self.do_again = True
+            self.accept()
+
     def prepare_search_and_replace(self):
         self.search_for.initialize('bulk_edit_search_for')
         self.replace_with.initialize('bulk_edit_replace_with')
@@ -243,7 +255,7 @@ class MetadataBulkDialog(QDialog, Ui_MetadataBulkDialog):
         fm = self.db.field_metadata
         for f in fm:
             if (f in ['author_sort'] or
-                    (fm[f]['datatype'] in ['text', 'series']
+                    (fm[f]['datatype'] in ['text', 'series', 'enumeration']
                      and fm[f].get('search_terms', None)
                      and f not in ['formats', 'ondevice', 'sort'])):
                 self.all_fields.append(f)
@@ -692,7 +704,6 @@ class MetadataBulkDialog(QDialog, Ui_MetadataBulkDialog):
         self.db.clean()
         return QDialog.accept(self)
 
-
     def series_changed(self, *args):
         self.write_series = True
 
