@@ -7,9 +7,11 @@ add/remove formats
 '''
 
 import os, re, time, traceback, textwrap
+from functools import partial
 
 from PyQt4.Qt import SIGNAL, QObject, Qt, QTimer, QThread, QDate, \
-    QPixmap, QListWidgetItem, QDialog, pyqtSignal, QMessageBox
+    QPixmap, QListWidgetItem, QDialog, pyqtSignal, QMessageBox, QIcon, \
+    QPushButton
 
 from calibre.gui2 import error_dialog, file_icon_provider, dynamic, \
                            choose_files, choose_images, ResizableDialog, \
@@ -31,7 +33,7 @@ from calibre.gui2.preferences.social import SocialMetadata
 from calibre.gui2.custom_column_widgets import populate_metadata_page
 from calibre import strftime
 
-class CoverFetcher(QThread):
+class CoverFetcher(QThread): # {{{
 
     def __init__(self, username, password, isbn, timeout, title, author):
         self.username = username.strip() if username else username
@@ -74,9 +76,9 @@ class CoverFetcher(QThread):
             self.traceback = traceback.format_exc()
             print self.traceback
 
+# }}}
 
-
-class Format(QListWidgetItem):
+class Format(QListWidgetItem): # {{{
 
     def __init__(self, parent, ext, size, path=None, timestamp=None):
         self.path = path
@@ -92,15 +94,70 @@ class Format(QListWidgetItem):
             self.setToolTip(text)
             self.setStatusTip(text)
 
+# }}}
+
 
 class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
 
     COVER_FETCH_TIMEOUT = 240 # seconds
     view_format = pyqtSignal(object)
 
+    # Cover processing {{{
+
+    def set_cover(self):
+        mi, ext = self.get_selected_format_metadata()
+        if mi is None:
+            return
+        cdata = None
+        if mi.cover and os.access(mi.cover, os.R_OK):
+            cdata = open(mi.cover).read()
+        elif mi.cover_data[1] is not None:
+            cdata = mi.cover_data[1]
+        if cdata is None:
+            error_dialog(self, _('Could not read cover'),
+                         _('Could not read cover from %s format')%ext).exec_()
+            return
+        pix = QPixmap()
+        pix.loadFromData(cdata)
+        if pix.isNull():
+            error_dialog(self, _('Could not read cover'),
+                         _('The cover in the %s format is invalid')%ext).exec_()
+            return
+        self.cover.setPixmap(pix)
+        self.update_cover_tooltip()
+        self.cover_changed = True
+        self.cpixmap = pix
+        self.cover_data = cdata
+
+    def trim_cover(self, *args):
+        from calibre.utils.magick import Image
+        cdata = self.cover_data
+        if not cdata:
+            return
+        im = Image()
+        im.load(cdata)
+        im.trim(10)
+        cdata = im.export('png')
+        pix = QPixmap()
+        pix.loadFromData(cdata)
+        self.cover.setPixmap(pix)
+        self.update_cover_tooltip()
+        self.cover_changed = True
+        self.cpixmap = pix
+        self.cover_data = cdata
+
+
+
+    def update_cover_tooltip(self):
+        p = self.cover.pixmap()
+        self.cover.setToolTip(_('Cover size: %dx%d pixels') %
+                (p.width(), p.height()))
+
+
     def do_reset_cover(self, *args):
         pix = QPixmap(I('default_cover.png'))
         self.cover.setPixmap(pix)
+        self.update_cover_tooltip()
         self.cover_changed = True
         self.cover_data = None
 
@@ -136,6 +193,7 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
                 else:
                     self.cover_path.setText(_file)
                     self.cover.setPixmap(pix)
+                    self.update_cover_tooltip()
                     self.cover_changed = True
                     self.cpixmap = pix
                     self.cover_data = cover
@@ -161,9 +219,80 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
         pix = QPixmap()
         pix.loadFromData(self.cover_data)
         self.cover.setPixmap(pix)
+        self.update_cover_tooltip()
         self.cover_changed = True
         self.cpixmap = pix
 
+    def cover_dropped(self, cover_data):
+        self.cover_changed = True
+        self.cover_data = cover_data
+        self.update_cover_tooltip()
+
+    def fetch_cover(self):
+        isbn   = re.sub(r'[^0-9a-zA-Z]', '', unicode(self.isbn.text())).strip()
+        self.fetch_cover_button.setEnabled(False)
+        self.setCursor(Qt.WaitCursor)
+        title, author = map(unicode, (self.title.text(), self.authors.text()))
+        self.cover_fetcher = CoverFetcher(None, None, isbn,
+                                            self.timeout, title, author)
+        self.cover_fetcher.start()
+        self._hangcheck = QTimer(self)
+        self.connect(self._hangcheck, SIGNAL('timeout()'), self.hangcheck)
+        self.cf_start_time = time.time()
+        self.pi.start(_('Downloading cover...'))
+        self._hangcheck.start(100)
+
+    def hangcheck(self):
+        if not self.cover_fetcher.isFinished() and \
+            time.time()-self.cf_start_time < self.COVER_FETCH_TIMEOUT:
+            return
+
+        self._hangcheck.stop()
+        try:
+            if self.cover_fetcher.isRunning():
+                self.cover_fetcher.terminate()
+                error_dialog(self, _('Cannot fetch cover'),
+                    _('<b>Could not fetch cover.</b><br/>')+
+                    _('The download timed out.')).exec_()
+                return
+            if self.cover_fetcher.needs_isbn:
+                error_dialog(self, _('Cannot fetch cover'),
+                    _('Could not find cover for this book. Try '
+                      'specifying the ISBN first.')).exec_()
+                return
+            if self.cover_fetcher.exception is not None:
+                err = self.cover_fetcher.exception
+                error_dialog(self, _('Cannot fetch cover'),
+                    _('<b>Could not fetch cover.</b><br/>')+unicode(err)).exec_()
+                return
+            if self.cover_fetcher.errors and self.cover_fetcher.cover_data is None:
+                details = u'\n\n'.join([e[-1] + ': ' + e[1] for e in self.cover_fetcher.errors])
+                error_dialog(self, _('Cannot fetch cover'),
+                    _('<b>Could not fetch cover.</b><br/>') +
+                    _('For the error message from each cover source, '
+                      'click Show details below.'), det_msg=details, show=True)
+                return
+
+            pix = QPixmap()
+            pix.loadFromData(self.cover_fetcher.cover_data)
+            if pix.isNull():
+                error_dialog(self, _('Bad cover'),
+                             _('The cover is not a valid picture')).exec_()
+            else:
+                self.cover.setPixmap(pix)
+                self.update_cover_tooltip()
+                self.cover_changed = True
+                self.cpixmap = pix
+                self.cover_data = self.cover_fetcher.cover_data
+        finally:
+            self.fetch_cover_button.setEnabled(True)
+            self.unsetCursor()
+            self.pi.stop()
+
+
+    # }}}
+
+    # Formats processing {{{
     def add_format(self, x):
         files = choose_files(self, 'add formats dialog',
                              _("Choose formats for ") + unicode((self.title.text())),
@@ -276,48 +405,6 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             self.comments.setPlainText(mi.comments)
 
 
-    def set_cover(self):
-        mi, ext = self.get_selected_format_metadata()
-        if mi is None:
-            return
-        cdata = None
-        if mi.cover and os.access(mi.cover, os.R_OK):
-            cdata = open(mi.cover).read()
-        elif mi.cover_data[1] is not None:
-            cdata = mi.cover_data[1]
-        if cdata is None:
-            error_dialog(self, _('Could not read cover'),
-                         _('Could not read cover from %s format')%ext).exec_()
-            return
-        pix = QPixmap()
-        pix.loadFromData(cdata)
-        if pix.isNull():
-            error_dialog(self, _('Could not read cover'),
-                         _('The cover in the %s format is invalid')%ext).exec_()
-            return
-        self.cover.setPixmap(pix)
-        self.cover_changed = True
-        self.cpixmap = pix
-        self.cover_data = cdata
-
-    def trim_cover(self, *args):
-        from calibre.utils.magick import Image
-        cdata = self.cover_data
-        if not cdata:
-            return
-        im = Image()
-        im.load(cdata)
-        im.trim(10)
-        cdata = im.export('png')
-        pix = QPixmap()
-        pix.loadFromData(cdata)
-        self.cover.setPixmap(pix)
-        self.cover_changed = True
-        self.cpixmap = pix
-        self.cover_data = cdata
-
-
-
     def sync_formats(self):
         old_extensions, new_extensions, paths = set(), set(), {}
         for row in range(self.formats.count()):
@@ -338,11 +425,14 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             if ext not in extensions:
                 self.db.remove_format(self.row, ext, notify=False)
 
-    def do_cancel_all(self):
-        self.cancel_all = True
-        self.reject()
+    def show_format(self, item, *args):
+        fmt = item.ext
+        self.view_format.emit(fmt)
 
-    def __init__(self, window, row, db, accepted_callback=None, cancel_all=False):
+    # }}}
+
+    def __init__(self, window, row, db, prev=None,
+            next_=None):
         ResizableDialog.__init__(self, window)
         self.bc_box.layout().setAlignment(self.cover, Qt.AlignCenter|Qt.AlignHCenter)
         self.cancel_all = False
@@ -354,16 +444,27 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
                 _(' The red color indicates that the current '
                     'author sort does not match the current author'))
 
-        if cancel_all:
-            self.__abort_button = self.button_box.addButton(self.button_box.Abort)
-            self.__abort_button.setToolTip(_('Abort the editing of all remaining books'))
-            self.connect(self.__abort_button, SIGNAL('clicked()'),
-                    self.do_cancel_all)
+        self.row_delta = 0
+        if prev:
+            self.prev_button = QPushButton(QIcon(I('back.png')), _('Previous'),
+                    self)
+            self.button_box.addButton(self.prev_button, self.button_box.ActionRole)
+            tip = _('Save changes and edit the metadata of %s')%prev
+            self.prev_button.setToolTip(tip)
+            self.prev_button.clicked.connect(partial(self.next_triggered,
+                -1))
+        if next_:
+            self.next_button = QPushButton(QIcon(I('forward.png')), _('Next'),
+                    self)
+            self.button_box.addButton(self.next_button, self.button_box.ActionRole)
+            tip = _('Save changes and edit the metadata of %s')%next_
+            self.next_button.setToolTip(tip)
+            self.next_button.clicked.connect(partial(self.next_triggered, 1))
+
         self.splitter.setStretchFactor(100, 1)
         self.read_state()
         self.db = db
         self.pi = ProgressIndicator(self)
-        self.accepted_callback = accepted_callback
         self.id = db.id(row)
         self.row = row
         self.cover_data = None
@@ -412,6 +513,8 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
         self.connect(self.reset_cover, SIGNAL('clicked()'), self.do_reset_cover)
         self.connect(self.swap_button, SIGNAL('clicked()'), self.swap_title_author)
         self.timeout = float(prefs['network_timeout'])
+
+
         self.title.setText(db.title(row))
         isbn = db.isbn(self.id, index_is_id=True)
         if not isbn:
@@ -472,6 +575,7 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
         else:
             self.cover_data = cover
         self.cover.setPixmap(pm)
+        self.update_cover_tooltip()
         self.original_series_name = unicode(self.series.text()).strip()
         if len(db.custom_column_label_map) == 0:
             self.central_widget.tabBar().setVisible(False)
@@ -479,6 +583,9 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             self.create_custom_column_editors()
         self.generate_cover_button.clicked.connect(self.generate_cover)
 
+        self.original_author = unicode(self.authors.text()).strip()
+        self.original_title = unicode(self.title.text()).strip()
+
     def create_custom_column_editors(self):
         w = self.central_widget.widget(1)
         layout = w.layout()
@@ -531,10 +638,6 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             self.isbn.setStyleSheet('QLineEdit { background-color: rgba(255,0,0,20%) }')
             self.isbn.setToolTip(_('This ISBN number is invalid'))
 
-    def show_format(self, item, *args):
-        fmt = item.ext
-        self.view_format.emit(fmt)
-
     def deduce_author_sort(self):
         au = unicode(self.authors.text())
         au = re.sub(r'\s+et al\.$', '', au)
@@ -547,9 +650,6 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
         self.authors.setText(title)
         self.author_sort.setText('')
 
-    def cover_dropped(self, cover_data):
-        self.cover_changed = True
-        self.cover_data = cover_data
 
     def initialize_combos(self):
         self.initalize_authors()
@@ -625,66 +725,6 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             self.tags.setText(tag_string)
             self.tags.update_tags_cache(self.db.all_tags())
 
-    def fetch_cover(self):
-        isbn   = re.sub(r'[^0-9a-zA-Z]', '', unicode(self.isbn.text())).strip()
-        self.fetch_cover_button.setEnabled(False)
-        self.setCursor(Qt.WaitCursor)
-        title, author = map(unicode, (self.title.text(), self.authors.text()))
-        self.cover_fetcher = CoverFetcher(None, None, isbn,
-                                            self.timeout, title, author)
-        self.cover_fetcher.start()
-        self._hangcheck = QTimer(self)
-        self.connect(self._hangcheck, SIGNAL('timeout()'), self.hangcheck)
-        self.cf_start_time = time.time()
-        self.pi.start(_('Downloading cover...'))
-        self._hangcheck.start(100)
-
-    def hangcheck(self):
-        if not self.cover_fetcher.isFinished() and \
-            time.time()-self.cf_start_time < self.COVER_FETCH_TIMEOUT:
-            return
-
-        self._hangcheck.stop()
-        try:
-            if self.cover_fetcher.isRunning():
-                self.cover_fetcher.terminate()
-                error_dialog(self, _('Cannot fetch cover'),
-                    _('<b>Could not fetch cover.</b><br/>')+
-                    _('The download timed out.')).exec_()
-                return
-            if self.cover_fetcher.needs_isbn:
-                error_dialog(self, _('Cannot fetch cover'),
-                    _('Could not find cover for this book. Try '
-                      'specifying the ISBN first.')).exec_()
-                return
-            if self.cover_fetcher.exception is not None:
-                err = self.cover_fetcher.exception
-                error_dialog(self, _('Cannot fetch cover'),
-                    _('<b>Could not fetch cover.</b><br/>')+unicode(err)).exec_()
-                return
-            if self.cover_fetcher.errors and self.cover_fetcher.cover_data is None:
-                details = u'\n\n'.join([e[-1] + ': ' + e[1] for e in self.cover_fetcher.errors])
-                error_dialog(self, _('Cannot fetch cover'),
-                    _('<b>Could not fetch cover.</b><br/>') +
-                    _('For the error message from each cover source, '
-                      'click Show details below.'), det_msg=details, show=True)
-                return
-
-            pix = QPixmap()
-            pix.loadFromData(self.cover_fetcher.cover_data)
-            if pix.isNull():
-                error_dialog(self, _('Bad cover'),
-                             _('The cover is not a valid picture')).exec_()
-            else:
-                self.cover.setPixmap(pix)
-                self.cover_changed = True
-                self.cpixmap = pix
-                self.cover_data = self.cover_fetcher.cover_data
-        finally:
-            self.fetch_cover_button.setEnabled(True)
-            self.unsetCursor()
-            self.pi.stop()
-
 
     def fetch_metadata(self):
         isbn   = re.sub(r'[^0-9a-zA-Z]', '', unicode(self.isbn.text()))
@@ -776,6 +816,10 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             unicode(self.tags.text()).split(',')],
                 notify=notify, commit=commit)
 
+    def next_triggered(self, row_delta, *args):
+        self.row_delta = row_delta
+        self.accept()
+
     def accept(self):
         cf = getattr(self, 'cover_fetcher', None)
         if cf is not None and hasattr(cf, 'terminate'):
@@ -785,9 +829,10 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             if self.formats_changed:
                 self.sync_formats()
             title = unicode(self.title.text()).strip()
-            self.db.set_title(self.id, title, notify=False)
+            if title != self.original_title:
+                self.db.set_title(self.id, title, notify=False)
             au = unicode(self.authors.text()).strip()
-            if au:
+            if au and au != self.original_author:
                 self.db.set_authors(self.id, string_to_authors(au), notify=False)
             aus = unicode(self.author_sort.text()).strip()
             if aus:
@@ -837,8 +882,6 @@ class MetadataSingleDialog(ResizableDialog, Ui_MetadataSingleDialog):
             raise
         self.save_state()
         QDialog.accept(self)
-        if callable(self.accepted_callback):
-            self.accepted_callback(self.id)
 
     def reject(self, *args):
         cf = getattr(self, 'cover_fetcher', None)
