@@ -51,7 +51,7 @@ class TagCategories(QDialog, Ui_TagCategories):
 
         cc_map = self.db.custom_column_label_map
         for cc in cc_map:
-            if cc_map[cc]['datatype'] == 'text':
+            if cc_map[cc]['datatype'] in ['text', 'series']:
                 self.category_labels.append(db.field_metadata.label_to_key(cc))
                 category_icons.append(cc_icon)
                 category_values.append(lambda col=cc: self.db.all_custom(label=col))
