@@ -565,8 +565,9 @@ datatype is one of: {0}
                           'applies if datatype is text.'))
     parser.add_option('--display', default='{}',
             help=_('A dictionary of options to customize how '
-                'the data in this column will be interpreted.'))
-
+                'the data in this column will be interpreted. This is a JSON '
+                ' string. For enumeration columns, use '
+                '--display=\'{"enum_values":["val1", "val2"]}\''))
     return parser
 
 
@@ -640,7 +641,7 @@ def catalog_option_parser(args):
     log = Log()
     parser = get_parser(_(
     '''
-    %prog catalog /path/to/destination.(csv|epub|mobi|xml ...) [options]
+    %prog catalog /path/to/destination.(CSV|EPUB|MOBI|XML ...) [options]
 
     Export a catalog in format specified by path/to/destination extension.
     Options control how entries are displayed in the generated catalog ouput.
