@@ -11,11 +11,15 @@ from calibre.constants import preferred_encoding
 from calibre.ebooks.BeautifulSoup import BeautifulSoup, Tag, NavigableString, \
         CData, Comment, Declaration, ProcessingInstruction
 from calibre import prepare_string_for_xml
+from calibre.utils.html2text import html2text
+from calibre.ebooks.markdown import markdown
 
 # Hackish - ignoring sentences ending or beginning in numbers to avoid
 # confusion with decimal points.
 lost_cr_pat = re.compile('([a-z])([\.\?!])([A-Z])')
 lost_cr_exception_pat = re.compile(r'(Ph\.D)|(D\.Phil)|((Dr|Mr|Mrs|Ms)\.[A-Z])')
+sanitize_pat = re.compile(r'<script|<table|<tr|<td|<th|<style|<iframe',
+        re.IGNORECASE)
 
 def comments_to_html(comments):
     '''
@@ -42,6 +46,8 @@ def comments_to_html(comments):
     Deprecated HTML returns as HTML via BeautifulSoup()
 
     '''
+    if not comments:
+        return u'<p></p>'
     if not isinstance(comments, unicode):
         comments = comments.decode(preferred_encoding, 'replace')
 
@@ -51,6 +57,15 @@ def comments_to_html(comments):
                 for x in comments.split('\n\n')]
         return '\n'.join(parts)
 
+    if sanitize_pat.search(comments) is not None:
+        try:
+            return sanitize_comments_html(comments)
+        except:
+            import traceback
+            traceback.print_exc()
+            return u'<p></p>'
+
+
     # Explode lost CRs to \n\n
     comments = lost_cr_exception_pat.sub(lambda m: m.group().replace('.',
         '.\r'), comments)
@@ -113,6 +128,12 @@ def comments_to_html(comments):
 
     return result.renderContents(encoding=None)
 
+def sanitize_comments_html(html):
+    text = html2text(html)
+    md = markdown.Markdown(safe_mode=True)
+    cleansed = re.sub('\n+', '', md.convert(text))
+    return cleansed
+
 def test():
     for pat, val in [
             ('lineone\n\nlinetwo',
