@@ -18,7 +18,7 @@ from calibre.utils.date import parse_date
 class CustomColumns(object):
 
     CUSTOM_DATA_TYPES = frozenset(['rating', 'text', 'comments', 'datetime',
-        'int', 'float', 'bool', 'series', 'composite'])
+        'int', 'float', 'bool', 'series', 'composite', 'enumeration'])
 
     def custom_table_names(self, num):
         return 'custom_column_%d'%num, 'books_custom_column_%d_link'%num
@@ -136,6 +136,12 @@ class CustomColumns(object):
                 x = bool(int(x))
             return x
 
+        def adapt_enum(x, d):
+            v = adapt_text(x, d)
+            if not v:
+                v = None
+            return v
+
         self.custom_data_adapters = {
                 'float': lambda x,d : x if x is None else float(x),
                 'int':   lambda x,d : x if x is None else int(x),
@@ -144,7 +150,8 @@ class CustomColumns(object):
                 'comments': lambda x,d: adapt_text(x, {'is_multiple':False}),
                 'datetime' : adapt_datetime,
                 'text':adapt_text,
-                'series':adapt_text
+                'series':adapt_text,
+                'enumeration': adapt_enum
         }
 
         # Create Tag Browser categories for custom columns
@@ -439,6 +446,9 @@ class CustomColumns(object):
         val = self.custom_data_adapters[data['datatype']](val, data)
 
         if data['normalized']:
+            if data['datatype'] == 'enumeration' and (
+                    val and val not in data['display']['enum_values']):
+                return None
             if not append or not data['is_multiple']:
                 self.conn.execute('DELETE FROM %s WHERE book=?'%lt, (id_,))
                 self.conn.execute(
@@ -558,7 +568,7 @@ class CustomColumns(object):
 
         if datatype in ('rating', 'int'):
             dt = 'INT'
-        elif datatype in ('text', 'comments', 'series', 'composite'):
+        elif datatype in ('text', 'comments', 'series', 'composite', 'enumeration'):
             dt = 'TEXT'
         elif datatype in ('float',):
             dt = 'REAL'
