@@ -10,6 +10,7 @@ import logging
 from logging.handlers import RotatingFileHandler
 
 import cherrypy
+from cherrypy.process.plugins import SimplePlugin
 
 from calibre.constants import __appname__, __version__
 from calibre.utils.date import fromtimestamp
@@ -22,20 +23,26 @@ from calibre.library.server.mobile import MobileServer
 from calibre.library.server.xml import XMLServer
 from calibre.library.server.opds import OPDSServer
 from calibre.library.server.cache import Cache
+from calibre.library.server.browse import BrowseServer
 
 
 class DispatchController(object): # {{{
 
-    def __init__(self):
+    def __init__(self, prefix, wsgi=False):
         self.dispatcher = cherrypy.dispatch.RoutesDispatcher()
         self.funcs = []
         self.seen = set([])
+        self.prefix = prefix if prefix else ''
+        if wsgi:
+            self.prefix = ''
 
     def __call__(self, name, route, func, **kwargs):
         if name in self.seen:
             raise NameError('Route name: '+ repr(name) + ' already used')
         self.seen.add(name)
         kwargs['action'] = 'f_%d'%len(self.funcs)
+        if route != '/':
+            route = self.prefix + route
         self.dispatcher.connect(name, route, self, **kwargs)
         self.funcs.append(expose(func))
 
@@ -53,49 +60,122 @@ class DispatchController(object): # {{{
 
 # }}}
 
-class LibraryServer(ContentServer, MobileServer, XMLServer, OPDSServer, Cache):
+class BonJour(SimplePlugin): # {{{
+
+    def __init__(self, engine, port=8080, prefix=''):
+        SimplePlugin.__init__(self, engine)
+        self.port = port
+        self.prefix = prefix
+
+    def start(self):
+        try:
+            publish_zeroconf('Books in calibre', '_stanza._tcp',
+                            self.port, {'path':self.prefix+'/stanza'})
+        except:
+            import traceback
+            cherrypy.log.error('Failed to start BonJour:')
+            cherrypy.log.error(traceback.format_exc())
+
+    start.priority = 90
+
+    def stop(self):
+        try:
+            stop_zeroconf()
+        except:
+            import traceback
+            cherrypy.log.error('Failed to stop BonJour:')
+            cherrypy.log.error(traceback.format_exc())
+
+
+    stop.priority = 10
+
+cherrypy.engine.bonjour = BonJour(cherrypy.engine)
+
+# }}}
+
+class LibraryServer(ContentServer, MobileServer, XMLServer, OPDSServer, Cache,
+        BrowseServer):
 
     server_name = __appname__ + '/' + __version__
 
-    def __init__(self, db, opts, embedded=False, show_tracebacks=True):
-        self.db = db
-        for item in self.db:
-            item
-            break
+    def __init__(self, db, opts, embedded=False, show_tracebacks=True,
+            wsgi=False):
+        self.is_wsgi = bool(wsgi)
         self.opts = opts
         self.embedded = embedded
+        self.state_callback = None
         self.max_cover_width, self.max_cover_height = \
                         map(int, self.opts.max_cover.split('x'))
         path = P('content_server')
         self.build_time = fromtimestamp(os.stat(path).st_mtime)
-        self.default_cover =  open(P('content_server/default_cover.jpg'), 'rb').read()
+        self.default_cover = open(P('content_server/default_cover.jpg'), 'rb').read()
+
+        cherrypy.engine.bonjour.port = opts.port
+        cherrypy.engine.bonjour.prefix = opts.url_prefix
+
+        Cache.__init__(self)
+
+        self.set_database(db)
+
         cherrypy.config.update({
-                                'log.screen'             : opts.develop,
-                                'engine.autoreload_on'   : opts.develop,
-                                'tools.log_headers.on'   : opts.develop,
-                                'checker.on'             : opts.develop,
-                                'request.show_tracebacks': show_tracebacks,
-                                'server.socket_host'     : listen_on,
-                                'server.socket_port'     : opts.port,
-                                'server.socket_timeout'  : opts.timeout, #seconds
-                                'server.thread_pool'     : opts.thread_pool, # number of threads
-                               })
-        if embedded:
+            'log.screen'             : opts.develop,
+            'engine.autoreload_on'   : getattr(opts,
+                                        'auto_reload', False),
+            'tools.log_headers.on'   : opts.develop,
+            'checker.on'             : opts.develop,
+            'request.show_tracebacks': show_tracebacks,
+            'server.socket_host'     : listen_on,
+            'server.socket_port'     : opts.port,
+            'server.socket_timeout'  : opts.timeout, #seconds
+            'server.thread_pool'     : opts.thread_pool, # number of threads
+        })
+        if embedded or wsgi:
             cherrypy.config.update({'engine.SIGHUP'          : None,
                                     'engine.SIGTERM'         : None,})
-        self.config = {'global': {
-            'tools.gzip.on'        : True,
-            'tools.gzip.mime_types': ['text/html', 'text/plain', 'text/xml', 'text/javascript', 'text/css'],
-        }}
-        if opts.password:
-            self.config['/'] = {
-                      'tools.digest_auth.on'    : True,
-                      'tools.digest_auth.realm' : (_('Password to access your calibre library. Username is ') + opts.username.strip()).encode('ascii', 'replace'),
-                      'tools.digest_auth.users' : {opts.username.strip():opts.password.strip()},
-                      }
-
+        self.config = {}
         self.is_running = False
         self.exception = None
+        if not wsgi:
+            self.setup_loggers()
+            cherrypy.engine.bonjour.subscribe()
+            self.config['global'] = {
+                'tools.gzip.on'        : True,
+                'tools.gzip.mime_types': ['text/html', 'text/plain',
+                    'text/xml', 'text/javascript', 'text/css'],
+            }
+            if opts.password:
+                self.config['/'] = {
+                        'tools.digest_auth.on'    : True,
+                        'tools.digest_auth.realm' : (
+                            'Password to access your calibre library. Username is '
+                            + opts.username.strip()),
+                        'tools.digest_auth.users' : {opts.username.strip():opts.password.strip()},
+                }
+
+        self.__dispatcher__ = DispatchController(self.opts.url_prefix, wsgi)
+        for x in self.__class__.__bases__:
+            if hasattr(x, 'add_routes'):
+                x.add_routes(self, self.__dispatcher__)
+        root_conf = self.config.get('/', {})
+        root_conf['request.dispatch'] = self.__dispatcher__.dispatcher
+        self.config['/'] = root_conf
+
+    def set_database(self, db):
+        self.db = db
+        sr = getattr(self.opts, 'restriction', None)
+        sr = db.prefs.get('cs_restriction', '') if sr is None else sr
+        self.set_search_restriction(sr)
+
+    def graceful(self):
+        cherrypy.engine.graceful()
+
+    def set_search_restriction(self, restriction):
+        self.search_restriction_name = restriction
+        if restriction:
+            self.search_restriction = 'search:"%s"'%restriction
+        else:
+            self.search_restriction = ''
+        self.reset_caches()
 
     def setup_loggers(self):
         access_file = log_access_file
@@ -119,15 +199,6 @@ class LibraryServer(ContentServer, MobileServer, XMLServer, OPDSServer, Cache):
 
     def start(self):
         self.is_running = False
-        d = DispatchController()
-        for x in self.__class__.__bases__:
-            if hasattr(x, 'add_routes'):
-                x.add_routes(self, d)
-        root_conf = self.config.get('/', {})
-        root_conf['request.dispatch'] = d.dispatcher
-        self.config['/'] = root_conf
-
-        self.setup_loggers()
         cherrypy.tree.mount(root=None, config=self.config)
         try:
             try:
@@ -141,29 +212,30 @@ class LibraryServer(ContentServer, MobileServer, XMLServer, OPDSServer, Cache):
                 cherrypy.engine.start()
 
             self.is_running = True
-            try:
-                publish_zeroconf('Books in calibre', '_stanza._tcp',
-                             self.opts.port, {'path':'/stanza'})
-            except:
-                import traceback
-                cherrypy.log.error('Failed to start BonJour:')
-                cherrypy.log.error(traceback.format_exc())
+            #if hasattr(cherrypy.engine, 'signal_handler'):
+            #    cherrypy.engine.signal_handler.subscribe()
+
             cherrypy.engine.block()
         except Exception, e:
             self.exception = e
         finally:
             self.is_running = False
             try:
-                stop_zeroconf()
+                if callable(self.state_callback):
+                    self.state_callback(self.is_running)
             except:
-                import traceback
-                cherrypy.log.error('Failed to stop BonJour:')
-                cherrypy.log.error(traceback.format_exc())
+                pass
 
     def exit(self):
         try:
             cherrypy.engine.exit()
         finally:
             cherrypy.server.httpserver = None
+            self.is_running = False
+            try:
+                if callable(self.state_callback):
+                    self.state_callback(self.is_running)
+            except:
+                pass
 
 
