@@ -61,8 +61,15 @@ def serialize_recipe(urn, recipe_class):
 
 def serialize_collection(mapping_of_recipe_classes):
     collection = E.recipe_collection()
-    for urn, recipe_class in mapping_of_recipe_classes.items():
-        recipe = serialize_recipe(urn, recipe_class)
+    '''for u, x in mapping_of_recipe_classes.items():
+        print 11111, u, repr(x.title)
+        if isinstance(x.title, str):
+            x.title.decode('ascii')
+    '''
+    for urn in sorted(mapping_of_recipe_classes.keys(),
+            key=lambda key: getattr(mapping_of_recipe_classes[key], 'title',
+                'zzz')):
+        recipe = serialize_recipe(urn, mapping_of_recipe_classes[urn])
         collection.append(recipe)
     collection.set('count', str(len(collection)))
     return etree.tostring(collection, encoding='utf-8', xml_declaration=True,
